@@ -170,7 +170,15 @@ class DownloadUtil extends BroadcastReceiver {
     DownloadManager.Query query = new DownloadManager.Query();
     query.setFilterByStatus(DownloadManager.STATUS_FAILED |
                             DownloadManager.STATUS_SUCCESSFUL);
-    Cursor c = dm.query(query);
+    Cursor c;
+
+    try {
+      c = dm.query(query);
+    } catch (Exception e) {
+      /* should not happen, but an SQLiteException has crashed XCSoar
+         on a Wiko Robby with Android 6.0 */
+      return;
+    }
 
     if (c == null)
       /* should not happen, but has been observed on Android 2.3 */
