@@ -648,7 +648,7 @@ NMEAParser::GGA(NMEAInputLine &line, NMEAInfo &info)
     // If the separation doesn't appear in the sentence,
     // we can assume the GPS unit is giving ellipsoid height
     //
-    if (use_geoid) {
+    if (use_geoid && info.location_available) {
       // JMW TODO really need to know the actual device..
       geoid_separation = EGM96::LookupSeparation(info.location);
       info.gps_altitude -= geoid_separation;
