@@ -326,7 +326,7 @@ public:
   void DrawFocusRectangle(PixelRect rc);
 
   gcc_pure
-  const PixelSize CalcTextSize(const TCHAR *text, size_t length) const;
+  const PixelSize CalcTextSize(TStringView text) const noexcept;
 
   gcc_pure
   const PixelSize CalcTextSize(const TCHAR *text) const;
