@@ -26,7 +26,7 @@ Copyright_License {
 #include <zzip/lib.h>
 
 static int
-jas_zzip_read(jas_stream_obj_t *obj, char *buf, int cnt)
+jas_zzip_read(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
   const auto f = (struct zzip_file *)obj;
 
@@ -34,7 +34,7 @@ jas_zzip_read(jas_stream_obj_t *obj, char *buf, int cnt)
 }
 
 static int
-jas_zzip_write(jas_stream_obj_t *obj, char *buf, int cnt)
+jas_zzip_write(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
   return -1;
 }
