@@ -71,8 +71,11 @@
 * Includes.
 \******************************************************************************/
 
-/* The configuration header file should be included first. */
-#include "jasper/jas_config.h"
+#include "jasper/jas_stream.h"
+#include "jasper/jas_debug.h"
+#include "jasper/jas_types.h"
+#include "jasper/jas_malloc.h"
+#include "jasper/jas_math.h"
 
 #include <assert.h>
 #if defined(JAS_HAVE_FCNTL_H)
@@ -81,6 +84,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #if defined(JAS_HAVE_UNISTD_H)
 #include <unistd.h>
@@ -89,12 +93,6 @@
 #include <io.h>
 #endif
 
-#include "jasper/jas_debug.h"
-#include "jasper/jas_types.h"
-#include "jasper/jas_stream.h"
-#include "jasper/jas_malloc.h"
-#include "jasper/jas_math.h"
-
 /******************************************************************************\
 * Local function prototypes.
 \******************************************************************************/
@@ -104,19 +102,19 @@ static int jas_strtoopenmode(const char *s);
 #endif /* JASPER_DISABLED */
 static void jas_stream_destroy(jas_stream_t *stream);
 
-static int mem_read(jas_stream_obj_t *obj, char *buf, int cnt);
-static int mem_write(jas_stream_obj_t *obj, char *buf, int cnt);
+static int mem_read(jas_stream_obj_t *obj, char *buf, unsigned cnt);
+static int mem_write(jas_stream_obj_t *obj, char *buf, unsigned cnt);
 static long mem_seek(jas_stream_obj_t *obj, long offset, int origin);
 static int mem_close(jas_stream_obj_t *obj);
 
 #ifdef JASPER_DISABLED
-static int sfile_read(jas_stream_obj_t *obj, char *buf, int cnt);
-static int sfile_write(jas_stream_obj_t *obj, char *buf, int cnt);
+static int sfile_read(jas_stream_obj_t *obj, char *buf, unsigned cnt);
+static int sfile_write(jas_stream_obj_t *obj, char *buf, unsigned cnt);
 static long sfile_seek(jas_stream_obj_t *obj, long offset, int origin);
 static int sfile_close(jas_stream_obj_t *obj);
 
-static int file_read(jas_stream_obj_t *obj, char *buf, int cnt);
-static int file_write(jas_stream_obj_t *obj, char *buf, int cnt);
+static int file_read(jas_stream_obj_t *obj, char *buf, unsigned cnt);
+static int file_write(jas_stream_obj_t *obj, char *buf, unsigned cnt);
 static long file_seek(jas_stream_obj_t *obj, long offset, int origin);
 static int file_close(jas_stream_obj_t *obj);
 #endif /* JASPER_DISABLED */
@@ -126,14 +124,14 @@ static int file_close(jas_stream_obj_t *obj);
 \******************************************************************************/
 
 #ifdef JASPER_DISABLED
-static jas_stream_ops_t jas_stream_fileops = {
+static const jas_stream_ops_t jas_stream_fileops = {
 	file_read,
 	file_write,
 	file_seek,
 	file_close
 };
 
-static jas_stream_ops_t jas_stream_sfileops = {
+static const jas_stream_ops_t jas_stream_sfileops = {
 	sfile_read,
 	sfile_write,
 	sfile_seek,
@@ -141,7 +139,7 @@ static jas_stream_ops_t jas_stream_sfileops = {
 };
 #endif /* JASPER_DISABLED */
 
-static jas_stream_ops_t jas_stream_memops = {
+static const jas_stream_ops_t jas_stream_memops = {
 	mem_read,
 	mem_write,
 	mem_seek,
@@ -454,7 +452,7 @@ jas_stream_t *jas_stream_freopen(const char *path, const char *mode, FILE *fp)
 	  fp));
 
 	/* Eliminate compiler warning about unused variable. */
-	path = 0;
+	(void)path;
 
 	/* Allocate a stream object. */
 	if (!(stream = jas_stream_create())) {
@@ -672,21 +670,16 @@ int jas_stream_ungetc(jas_stream_t *stream, int c)
 }
 
 /* FIXME integral type */
-int jas_stream_read(jas_stream_t *stream, void *buf, int cnt)
+int jas_stream_read(jas_stream_t *stream, void *buf, unsigned cnt)
 {
-	int n;
 	int c;
 	char *bufptr;
 
-	JAS_DBGLOG(100, ("jas_stream_read(%p, %p, %d)\n", stream, buf, cnt));
-
-	if (cnt < 0) {
-		jas_deprecated("negative count for jas_stream_read");
-	}
+	JAS_DBGLOG(100, ("jas_stream_read(%p, %p, %u)\n", stream, buf, cnt));
 
 	bufptr = buf;
 
-	n = 0;
+	unsigned n = 0;
 	while (n < cnt) {
 		if ((c = jas_stream_getc(stream)) == EOF) {
 			return n;
@@ -699,20 +692,15 @@ int jas_stream_read(jas_stream_t *stream, void *buf, int cnt)
 }
 
 /* FIXME integral type */
-int jas_stream_write(jas_stream_t *stream, const void *buf, int cnt)
+int jas_stream_write(jas_stream_t *stream, const void *buf, unsigned cnt)
 {
-	int n;
 	const char *bufptr;
 
 	JAS_DBGLOG(100, ("jas_stream_write(%p, %p, %d)\n", stream, buf, cnt));
 
-	if (cnt < 0) {
-		jas_deprecated("negative count for jas_stream_write");
-	}
-
 	bufptr = buf;
 
-	n = 0;
+	unsigned n = 0;
 	while (n < cnt) {
 		if (jas_stream_putc(stream, *bufptr) == EOF) {
 			return n;
@@ -1193,14 +1181,13 @@ long jas_stream_length(jas_stream_t *stream)
 \******************************************************************************/
 
 /* FIXME integral type */
-static int mem_read(jas_stream_obj_t *obj, char *buf, int cnt)
+static int mem_read(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
 	ssize_t n;
 	jas_stream_memobj_t *m;
-	assert(cnt >= 0);
 	assert(buf);
 
-	JAS_DBGLOG(100, ("mem_read(%p, %p, %d)\n", obj, buf, cnt));
+	JAS_DBGLOG(100, ("mem_read(%p, %p, %u)\n", obj, buf, cnt));
 	m = (jas_stream_memobj_t *)obj;
 	n = m->len_ - m->pos_;
 	cnt = JAS_MIN(n, cnt);
@@ -1214,7 +1201,6 @@ static int mem_resize(jas_stream_memobj_t *m, size_t bufsize)
 	unsigned char *buf;
 
 	//assert(m->buf_);
-	//assert(bufsize >= 0);
 
 	JAS_DBGLOG(100, ("mem_resize(%p, %zu)\n", m, bufsize));
 	if (!bufsize) {
@@ -1236,18 +1222,16 @@ static int mem_resize(jas_stream_memobj_t *m, size_t bufsize)
 }
 
 /* FIXME integral type */
-static int mem_write(jas_stream_obj_t *obj, char *buf, int cnt)
+static int mem_write(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
 	size_t n;
-	int ret;
 	jas_stream_memobj_t *m = (jas_stream_memobj_t *)obj;
 	size_t newbufsize;
 	size_t newpos;
 
 	assert(buf);
-	assert(cnt >= 0);
 
-	JAS_DBGLOG(100, ("mem_write(%p, %p, %d)\n", obj, buf, cnt));
+	JAS_DBGLOG(100, ("mem_write(%p, %p, %u)\n", obj, buf, cnt));
 	newpos = m->pos_ + cnt;
 	if (newpos > m->bufsize_ && m->growable_) {
 		newbufsize = m->bufsize_;
@@ -1279,7 +1263,7 @@ static int mem_write(jas_stream_obj_t *obj, char *buf, int cnt)
 		}
 	}
 	n = m->bufsize_ - m->pos_;
-	ret = JAS_MIN(n, cnt);
+	unsigned ret = JAS_MIN(n, cnt);
 	if (ret > 0) {
 		memcpy(&m->buf_[m->pos_], buf, ret);
 		m->pos_ += ret;
@@ -1295,7 +1279,7 @@ static int mem_write(jas_stream_obj_t *obj, char *buf, int cnt)
 static long mem_seek(jas_stream_obj_t *obj, long offset, int origin)
 {
 	jas_stream_memobj_t *m = (jas_stream_memobj_t *)obj;
-	size_t newpos;
+	ssize_t newpos;
 
 	JAS_DBGLOG(100, ("mem_seek(%p, %ld, %d)\n", obj, offset, origin));
 	switch (origin) {
@@ -1342,19 +1326,19 @@ static int mem_close(jas_stream_obj_t *obj)
 
 #ifdef JASPER_DISABLED
 /* FIXME integral type */
-static int file_read(jas_stream_obj_t *obj, char *buf, int cnt)
+static int file_read(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
 	jas_stream_fileobj_t *fileobj;
-	JAS_DBGLOG(100, ("file_read(%p, %p, %d)\n", obj, buf, cnt));
+	JAS_DBGLOG(100, ("file_read(%p, %p, %u)\n", obj, buf, cnt));
 	fileobj = JAS_CAST(jas_stream_fileobj_t *, obj);
 	return read(fileobj->fd, buf, cnt);
 }
 
 /* FIXME integral type */
-static int file_write(jas_stream_obj_t *obj, char *buf, int cnt)
+static int file_write(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
 	jas_stream_fileobj_t *fileobj;
-	JAS_DBGLOG(100, ("file_write(%p, %p, %d)\n", obj, buf, cnt));
+	JAS_DBGLOG(100, ("file_write(%p, %p, %u)\n", obj, buf, cnt));
 	fileobj = JAS_CAST(jas_stream_fileobj_t *, obj);
 	return write(fileobj->fd, buf, cnt);
 }
@@ -1387,12 +1371,12 @@ static int file_close(jas_stream_obj_t *obj)
 \******************************************************************************/
 
 /* FIXME integral type */
-static int sfile_read(jas_stream_obj_t *obj, char *buf, int cnt)
+static int sfile_read(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
 	FILE *fp;
 	size_t n;
 	int result;
-	JAS_DBGLOG(100, ("sfile_read(%p, %p, %d)\n", obj, buf, cnt));
+	JAS_DBGLOG(100, ("sfile_read(%p, %p, %u)\n", obj, buf, cnt));
 	fp = JAS_CAST(FILE *, obj);
 	n = fread(buf, 1, cnt, fp);
 	if (n != cnt) {
@@ -1403,14 +1387,14 @@ static int sfile_read(jas_stream_obj_t *obj, char *buf, int cnt)
 }
 
 /* FIXME integral type */
-static int sfile_write(jas_stream_obj_t *obj, char *buf, int cnt)
+static int sfile_write(jas_stream_obj_t *obj, char *buf, unsigned cnt)
 {
 	FILE *fp;
 	size_t n;
 	JAS_DBGLOG(100, ("sfile_write(%p, %p, %d)\n", obj, buf, cnt));
 	fp = JAS_CAST(FILE *, obj);
 	n = fwrite(buf, 1, cnt, fp);
-	return (n != JAS_CAST(size_t, cnt)) ? (-1) : cnt;
+	return (n != cnt) ? (-1) : (int)cnt;
 }
 
 /* FIXME integral type */
