@@ -77,11 +77,6 @@
 
 #include <stdio.h>
 
-#include <jasper/jas_types.h>
-#include <jasper/jas_debug.h>
-
-#include "Compiler.h"
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -101,7 +96,7 @@ extern "C" {
 
 #ifdef ENABLE_JASPER_LOG
 /* Get the library debug level. */
-gcc_const
+JAS_ATTRIBUTE_CONST
 JAS_DLLEXPORT int jas_getdbglevel(void);
 
 /* Set the library debug level. */
