@@ -78,8 +78,9 @@
 #include <jasper/jas_config.h>
 
 #include <jasper/jas_stream.h>
-#include <jasper/jas_seq.h>
-#include <jasper/jas_cm.h>
+#include <jasper/jas_types.h>
+#include <jasper/jas_seq.h> /* IWYU pragma: export */
+#include <jasper/jas_cm.h> /* IWYU pragma: export */
 #include <stdio.h>
 
 #ifdef __cplusplus
@@ -204,10 +205,10 @@ typedef struct {
 	/* The y-coordinate of the bottom-right corner of the image bounding
 	  box (plus one). */
 
-	int numcmpts_;
+	unsigned numcmpts_;
 	/* The number of components. */
 
-	int maxcmpts_;
+	unsigned maxcmpts_;
 	/* The maximum number of components that this image can have (i.e., the
 	  allocated size of the components array). */
 
@@ -306,8 +307,8 @@ typedef struct {
 \******************************************************************************/
 
 /* Create an image. */
-JAS_DLLEXPORT jas_image_t *jas_image_create(int numcmpts,
-  jas_image_cmptparm_t *cmptparms, jas_clrspc_t clrspc);
+JAS_DLLEXPORT jas_image_t *jas_image_create(unsigned numcmpts,
+  const jas_image_cmptparm_t *cmptparms, jas_clrspc_t clrspc);
 
 /* Create an "empty" image. */
 JAS_DLLEXPORT jas_image_t *jas_image_create0(void);
@@ -408,11 +409,13 @@ JAS_DLLEXPORT void jas_image_destroy(jas_image_t *image);
 	  (image)->cmpts_[cmptno]->vstep_)
 
 // Test if all components are specified at the same positions in space. */
-JAS_DLLEXPORT bool jas_image_cmpt_domains_same(jas_image_t *image);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT bool jas_image_cmpt_domains_same(const jas_image_t *image);
 
 /* Get the raw size of an image (i.e., the nominal size of the image without
   any compression. */
-JAS_DLLEXPORT uint_fast32_t jas_image_rawsize(jas_image_t *image);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT uint_fast32_t jas_image_rawsize(const jas_image_t *image);
 
 /* Create an image from a stream in some specified format. */
 JAS_DLLEXPORT jas_image_t *jas_image_decode(jas_stream_t *in, int fmt, const char *optstr);
@@ -424,42 +427,66 @@ JAS_DLLEXPORT int jas_image_encode(jas_image_t *image, jas_stream_t *out, int fm
 /* Read a rectangular region of an image component. */
 /* The position and size of the rectangular region to be read is specified
 relative to the component's coordinate system. */
-JAS_DLLEXPORT int jas_image_readcmpt(jas_image_t *image, int cmptno, jas_image_coord_t x,
+JAS_DLLEXPORT int jas_image_readcmpt(jas_image_t *image, unsigned cmptno, jas_image_coord_t x,
   jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
   jas_matrix_t *data);
 
 /* Write a rectangular region of an image component. */
-JAS_DLLEXPORT int jas_image_writecmpt(jas_image_t *image, int cmptno, jas_image_coord_t x,
+JAS_DLLEXPORT int jas_image_writecmpt(jas_image_t *image, unsigned cmptno, jas_image_coord_t x,
   jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
-  jas_matrix_t *data);
+  const jas_matrix_t *data);
 
 /* Delete a component from an image. */
-JAS_DLLEXPORT void jas_image_delcmpt(jas_image_t *image, int cmptno);
+JAS_DLLEXPORT void jas_image_delcmpt(jas_image_t *image, unsigned cmptno);
 
 /* Add a component to an image. */
 JAS_DLLEXPORT int jas_image_addcmpt(jas_image_t *image, int cmptno,
-  jas_image_cmptparm_t *cmptparm);
+  const jas_image_cmptparm_t *cmptparm);
 
 /* Copy a component from one image to another. */
-JAS_DLLEXPORT int jas_image_copycmpt(jas_image_t *dstimage, int dstcmptno,
-  jas_image_t *srcimage, int srccmptno);
+JAS_DLLEXPORT int jas_image_copycmpt(jas_image_t *dstimage, unsigned dstcmptno,
+  jas_image_t *srcimage, unsigned srccmptno);
 
-#define	JAS_IMAGE_CDT_GETSGND(dtype) (((dtype) >> 7) & 1)
-#define	JAS_IMAGE_CDT_SETSGND(dtype) (((dtype) & 1) << 7)
-#define	JAS_IMAGE_CDT_GETPREC(dtype) ((dtype) & 0x7f)
-#define	JAS_IMAGE_CDT_SETPREC(dtype) ((dtype) & 0x7f)
+JAS_ATTRIBUTE_CONST
+static inline bool JAS_IMAGE_CDT_GETSGND(uint_least8_t dtype)
+{
+	return (dtype >> 7) & 1;
+}
 
-#define	jas_image_cmptdtype(image, cmptno) \
-	(JAS_IMAGE_CDT_SETSGND((image)->cmpts_[cmptno]->sgnd_) | JAS_IMAGE_CDT_SETPREC((image)->cmpts_[cmptno]->prec_))
+JAS_ATTRIBUTE_CONST
+static inline uint_least8_t JAS_IMAGE_CDT_SETSGND(bool sgnd)
+{
+	return (uint_least8_t)sgnd << 7;
+}
 
-JAS_DLLEXPORT int jas_image_depalettize(jas_image_t *image, int cmptno, int numlutents,
-  int_fast32_t *lutents, int dtype, int newcmptno);
+JAS_ATTRIBUTE_CONST
+static inline uint_least8_t JAS_IMAGE_CDT_GETPREC(uint_least8_t dtype)
+{
+	return dtype & 0x7f;
+}
 
-JAS_DLLEXPORT int jas_image_readcmptsample(jas_image_t *image, int cmptno, int x, int y);
-JAS_DLLEXPORT void jas_image_writecmptsample(jas_image_t *image, int cmptno, int x, int y,
+JAS_ATTRIBUTE_CONST
+static inline uint_least8_t JAS_IMAGE_CDT_SETPREC(uint_least8_t dtype)
+{
+	return dtype & 0x7f;
+}
+
+JAS_ATTRIBUTE_PURE
+static inline uint_least8_t jas_image_cmptdtype(const jas_image_t *image, unsigned cmptno)
+{
+	return JAS_IMAGE_CDT_SETSGND(image->cmpts_[cmptno]->sgnd_) |
+		JAS_IMAGE_CDT_SETPREC(image->cmpts_[cmptno]->prec_);
+}
+
+JAS_DLLEXPORT int jas_image_depalettize(jas_image_t *image, unsigned cmptno, unsigned numlutents,
+  const int_fast32_t *lutents, int dtype, unsigned newcmptno);
+
+JAS_DLLEXPORT int jas_image_readcmptsample(jas_image_t *image, unsigned cmptno, int x, int y);
+JAS_DLLEXPORT void jas_image_writecmptsample(jas_image_t *image, unsigned cmptno, int x, int y,
   int_fast32_t v);
 
-JAS_DLLEXPORT int jas_image_getcmptbytype(jas_image_t *image, int ctype);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT int jas_image_getcmptbytype(const jas_image_t *image, int ctype);
 
 /******************************************************************************\
 * Image format-related operations.
@@ -470,36 +497,43 @@ JAS_DLLEXPORT void jas_image_clearfmts(void);
 
 /* Add entry to table of image formats. */
 JAS_DLLEXPORT int jas_image_addfmt(int id, const char *name, const char *ext, const char *desc,
-  jas_image_fmtops_t *ops);
+  const jas_image_fmtops_t *ops);
 
 /* Get the ID for the image format with the specified name. */
-JAS_DLLEXPORT int jas_image_strtofmt(char *s);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT int jas_image_strtofmt(const char *s);
 
 /* Get the name of the image format with the specified ID. */
-JAS_DLLEXPORT char *jas_image_fmttostr(int fmt);
+JAS_ATTRIBUTE_CONST
+JAS_DLLEXPORT const char *jas_image_fmttostr(int fmt);
 
 /* Lookup image format information by the format ID. */
-JAS_DLLEXPORT jas_image_fmtinfo_t *jas_image_lookupfmtbyid(int id);
+JAS_ATTRIBUTE_CONST
+JAS_DLLEXPORT const jas_image_fmtinfo_t *jas_image_lookupfmtbyid(int id);
 
 /* Lookup image format information by the format name. */
-JAS_DLLEXPORT jas_image_fmtinfo_t *jas_image_lookupfmtbyname(const char *name);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT const jas_image_fmtinfo_t *jas_image_lookupfmtbyname(const char *name);
 
 /* Guess the format of an image file based on its name. */
-JAS_DLLEXPORT int jas_image_fmtfromname(char *filename);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT int jas_image_fmtfromname(const char *filename);
 
 /* Get the format of image data in a stream. */
+JAS_ATTRIBUTE_PURE
 JAS_DLLEXPORT int jas_image_getfmt(jas_stream_t *in);
 
 
 #define	jas_image_cmprof(image)	((image)->cmprof_)
-int jas_image_ishomosamp(jas_image_t *image);
-int jas_image_sampcmpt(jas_image_t *image, int cmptno, int newcmptno,
+JAS_ATTRIBUTE_PURE
+int jas_image_ishomosamp(const jas_image_t *image);
+int jas_image_sampcmpt(jas_image_t *image, unsigned cmptno, unsigned newcmptno,
   jas_image_coord_t ho, jas_image_coord_t vo, jas_image_coord_t hs,
   jas_image_coord_t vs, int sgnd, int prec);
-int jas_image_writecmpt2(jas_image_t *image, int cmptno, jas_image_coord_t x,
+int jas_image_writecmpt2(jas_image_t *image, unsigned cmptno, jas_image_coord_t x,
   jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
-  long *buf);
-int jas_image_readcmpt2(jas_image_t *image, int cmptno, jas_image_coord_t x,
+  const long *buf);
+int jas_image_readcmpt2(jas_image_t *image, unsigned cmptno, jas_image_coord_t x,
   jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
   long *buf);
 
