@@ -120,15 +120,15 @@ typedef struct {
 \******************************************************************************/
 
 /* Lookup a tag by name. */
-gcc_pure
-JAS_DLLEXPORT jas_taginfo_t *jas_taginfos_lookup(jas_taginfo_t *taginfos, const char *name);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT const jas_taginfo_t *jas_taginfos_lookup(const jas_taginfo_t *taginfos, const char *name);
 
 /* This function returns a pointer to the specified taginfo object if it
   exists (i.e., the pointer is nonnull); otherwise, a pointer to a dummy
   object is returned.  This is useful in some situations to avoid checking
   for a null pointer. */
-gcc_pure
-JAS_DLLEXPORT jas_taginfo_t *jas_taginfo_nonull(jas_taginfo_t *taginfo);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT const jas_taginfo_t *jas_taginfo_nonull(const jas_taginfo_t *taginfo);
 
 /******************************************************************************\
 * Tag-value parser functions.
@@ -145,12 +145,12 @@ JAS_DLLEXPORT void jas_tvparser_destroy(jas_tvparser_t *tvparser);
 JAS_DLLEXPORT int jas_tvparser_next(jas_tvparser_t *tvparser);
 
 /* Get the tag name for the current tag-value pair. */
-gcc_pure
-JAS_DLLEXPORT char *jas_tvparser_gettag(jas_tvparser_t *tvparser);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT const char *jas_tvparser_gettag(const jas_tvparser_t *tvparser);
 
 /* Get the value for the current tag-value pair. */
-gcc_pure
-JAS_DLLEXPORT const char *jas_tvparser_getval(jas_tvparser_t *tvparser);
+JAS_ATTRIBUTE_PURE
+JAS_DLLEXPORT const char *jas_tvparser_getval(const jas_tvparser_t *tvparser);
 
 #ifdef __cplusplus
 }
