@@ -5,18 +5,13 @@
  * All rights reserved.
  */
 
-/*
- * Modified by Andrey Kiselev <dron@remotesensing.org> to handle UUID
- * box properly.
- */
-
 /* __START_OF_JASPER_LICENSE__
  * 
  * JasPer License Version 2.0
  * 
+ * Copyright (c) 2001-2006 Michael David Adams
  * Copyright (c) 1999-2000 Image Power, Inc.
  * Copyright (c) 1999-2000 The University of British Columbia
- * Copyright (c) 2001-2003 Michael David Adams
  * 
  * All rights reserved.
  * 
@@ -76,14 +71,13 @@
 * Includes.
 \******************************************************************************/
 
-#include <assert.h>
-#include <stdlib.h>
+#include "jp2_cod.h"
 
-#include "jasper/jas_stream.h"
 #include "jasper/jas_malloc.h"
 #include "jasper/jas_debug.h"
 
-#include "jp2_cod.h"
+#include <assert.h>
+#include <string.h>
 
 /******************************************************************************\
 * Function prototypes.
@@ -91,23 +85,40 @@
 
 #define	ONES(n)	((1 << (n)) - 1)
 
-jp2_boxinfo_t *jp2_boxinfolookup(int type);
+static const jp2_boxinfo_t *jp2_boxinfolookup(int type);
 
+#ifdef ENABLE_JASPER_IMAGE
 static int jp2_getuint8(jas_stream_t *in, uint_fast8_t *val);
 static int jp2_getuint16(jas_stream_t *in, uint_fast16_t *val);
+#endif /* ENABLE_JASPER_IMAGE */
 static int jp2_getuint32(jas_stream_t *in, uint_fast32_t *val);
 static int jp2_getuint64(jas_stream_t *in, uint_fast64_t *val);
+#ifdef JASPER_DISABLED
 static int jp2_putuint8(jas_stream_t *out, uint_fast8_t val);
 static int jp2_putuint16(jas_stream_t *out, uint_fast16_t val);
 static int jp2_putuint32(jas_stream_t *out, uint_fast32_t val);
 static int jp2_putuint64(jas_stream_t *out, uint_fast64_t val);
+#endif /* JASPER_DISABLED */
 
+#ifdef ENABLE_JASPER_IMAGE
 static int jp2_getint(jas_stream_t *in, int s, int n, int_fast32_t *val);
+#endif /* ENABLE_JASPER_IMAGE */
+
+#ifdef JASPER_DISABLED
+void jp2_box_dump(jp2_box_t *box, FILE *out);
+#else
+#define jp2_box_dump(box, out)
+#endif /* JASPER_DISABLED */
 
 static int jp2_jp_getdata(jp2_box_t *box, jas_stream_t *in);
+#ifdef JASPER_DISABLED
 static int jp2_jp_putdata(jp2_box_t *box, jas_stream_t *out);
+#endif /* JASPER_DISABLED */
 static int jp2_ftyp_getdata(jp2_box_t *box, jas_stream_t *in);
+#ifdef JASPER_DISABLED
 static int jp2_ftyp_putdata(jp2_box_t *box, jas_stream_t *out);
+#endif /* JASPER_DISABLED */
+#ifdef ENABLE_JASPER_IMAGE
 static int jp2_ihdr_getdata(jp2_box_t *box, jas_stream_t *in);
 static int jp2_ihdr_putdata(jp2_box_t *box, jas_stream_t *out);
 static void jp2_bpcc_destroy(jp2_box_t *box);
@@ -125,73 +136,89 @@ static int jp2_cmap_putdata(jp2_box_t *box, jas_stream_t *out);
 static void jp2_pclr_destroy(jp2_box_t *box);
 static int jp2_pclr_getdata(jp2_box_t *box, jas_stream_t *in);
 static int jp2_pclr_putdata(jp2_box_t *box, jas_stream_t *out);
-static void jp2_uuid_destroy(jp2_box_t *box);
-static int jp2_uuid_getdata(jp2_box_t *box, jas_stream_t *in);
-static int jp2_uuid_putdata(jp2_box_t *box, jas_stream_t *out);
+static void jp2_pclr_dumpdata(jp2_box_t *box, FILE *out);
+#endif /* ENABLE_JASPER_IMAGE */
 
 /******************************************************************************\
 * Local data.
 \******************************************************************************/
 
-jp2_boxinfo_t jp2_boxinfos[] = {
+static const jp2_boxinfo_t jp2_boxinfos[] = {
 	{JP2_BOX_JP, "JP", 0,
-	  {0, 0, jp2_jp_getdata, jp2_jp_putdata}},
+	  {0, 0, jp2_jp_getdata}},
 	{JP2_BOX_FTYP, "FTYP", 0,
-	  {0, 0, jp2_ftyp_getdata, jp2_ftyp_putdata}},
+	  {0, 0, jp2_ftyp_getdata}},
 	{JP2_BOX_JP2H, "JP2H", JP2_BOX_SUPER,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
+#ifdef ENABLE_JASPER_IMAGE
 	{JP2_BOX_IHDR, "IHDR", 0,
-	  {0, 0, jp2_ihdr_getdata, jp2_ihdr_putdata}},
+	  {0, 0, jp2_ihdr_getdata}},
 	{JP2_BOX_BPCC, "BPCC", 0,
-	  {0, jp2_bpcc_destroy, jp2_bpcc_getdata, jp2_bpcc_putdata}},
+	  {0, jp2_bpcc_destroy, jp2_bpcc_getdata}},
 	{JP2_BOX_COLR, "COLR", 0,
-	  {0, jp2_colr_destroy, jp2_colr_getdata, jp2_colr_putdata}},
+	  {0, jp2_colr_destroy, jp2_colr_getdata}},
 	{JP2_BOX_PCLR, "PCLR", 0,
-	  {0, jp2_pclr_destroy, jp2_pclr_getdata, jp2_pclr_putdata}},
+	  {0, jp2_pclr_destroy, jp2_pclr_getdata}},
 	{JP2_BOX_CMAP, "CMAP", 0,
-	  {0, jp2_cmap_destroy, jp2_cmap_getdata, jp2_cmap_putdata}},
+	  {0, jp2_cmap_destroy, jp2_cmap_getdata}},
 	{JP2_BOX_CDEF, "CDEF", 0,
-	  {0, jp2_cdef_destroy, jp2_cdef_getdata, jp2_cdef_putdata}},
+	  {0, jp2_cdef_destroy, jp2_cdef_getdata, jp2_cdef_putdata, jp2_cdef_dumpdata}},
+#endif /* ENABLE_JASPER_IMAGE */
 	{JP2_BOX_RES, "RES", JP2_BOX_SUPER,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_RESC, "RESC", 0,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_RESD, "RESD", 0,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_JP2C, "JP2C", JP2_BOX_NODATA,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_JP2I, "JP2I", 0,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_XML, "XML", 0,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_UUID, "UUID", 0,
-	  {0, jp2_uuid_destroy, jp2_uuid_getdata, jp2_uuid_putdata}},
+	  {0, 0, 0}},
 	{JP2_BOX_UINF, "UINF", JP2_BOX_SUPER,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_ULST, "ULST", 0,
-	  {0, 0, 0, 0}},
+	  {0, 0, 0}},
 	{JP2_BOX_URL, "URL", 0,
-	  {0, 0, 0, 0}},
-	{0, 0, 0, {0, 0, 0, 0}},
+	  {0, 0, 0}},
+	{0, 0, 0, {0, 0, 0}},
 };
 
-jp2_boxinfo_t jp2_boxinfo_unk = {
-	0, "Unknown", 0, {0, 0, 0, 0}
+static const jp2_boxinfo_t jp2_boxinfo_unk = {
+	0, "Unknown", 0, {0, 0, 0}
 };
 
 /******************************************************************************\
 * Box constructor.
 \******************************************************************************/
 
-jp2_box_t *jp2_box_create(int type)
+static jp2_box_t *jp2_box_create0(void)
 {
 	jp2_box_t *box;
-	jp2_boxinfo_t *boxinfo;
-
 	if (!(box = jas_malloc(sizeof(jp2_box_t)))) {
 		return 0;
 	}
 	memset(box, 0, sizeof(jp2_box_t));
+	box->type = 0;
+	box->len = 0;
+	// Mark the box data as never having been constructed
+	// so that we will not errantly attempt to destroy it later.
+	box->ops = &jp2_boxinfo_unk.ops;
+	return box;
+}
+
+#ifdef ENABLE_JASPER_ENCODE
+
+jp2_box_t *jp2_box_create(int type)
+{
+	jp2_box_t *box;
+	const jp2_boxinfo_t *boxinfo;
+	if (!(box = jp2_box_create0())) {
+		return 0;
+	}
 	box->type = type;
 	box->len = 0;
 	if (!(boxinfo = jp2_boxinfolookup(type))) {
@@ -202,6 +229,8 @@ jp2_box_t *jp2_box_create(int type)
 	return box;
 }
 
+#endif /* ENABLE_JASPER_ENCODE */
+
 /******************************************************************************\
 * Box destructor.
 \******************************************************************************/
@@ -214,6 +243,7 @@ void jp2_box_destroy(jp2_box_t *box)
 	jas_free(box);
 }
 
+#ifdef ENABLE_JASPER_IMAGE
 static void jp2_bpcc_destroy(jp2_box_t *box)
 {
 	jp2_bpcc_t *bpcc = &box->data.bpcc;
@@ -231,6 +261,7 @@ static void jp2_cdef_destroy(jp2_box_t *box)
 		cdef->ents = 0;
 	}
 }
+#endif /* ENABLE_JASPER_IMAGE */
 
 /******************************************************************************\
 * Box input.
@@ -239,7 +270,7 @@ static void jp2_cdef_destroy(jp2_box_t *box)
 jp2_box_t *jp2_box_get(jas_stream_t *in)
 {
 	jp2_box_t *box;
-	jp2_boxinfo_t *boxinfo;
+	const jp2_boxinfo_t *boxinfo;
 	jas_stream_t *tmpstream;
 	uint_fast32_t len;
 	uint_fast64_t extlen;
@@ -248,55 +279,79 @@ jp2_box_t *jp2_box_get(jas_stream_t *in)
 	box = 0;
 	tmpstream = 0;
 
-	if (!(box = jas_malloc(sizeof(jp2_box_t)))) {
+	if (!(box = jp2_box_create0())) {
 		goto error;
 	}
-	box->ops = &jp2_boxinfo_unk.ops;
 	if (jp2_getuint32(in, &len) || jp2_getuint32(in, &box->type)) {
 		goto error;
 	}
 	boxinfo = jp2_boxinfolookup(box->type);
 	box->info = boxinfo;
-	box->ops = &boxinfo->ops;
 	box->len = len;
-	box->data_len = box->len;
+	JAS_DBGLOG(10, (
+	  "preliminary processing of JP2 box: "
+	  "type=%c%s%c (0x%08x); length=%"PRIuFAST32"\n",
+	  '"', boxinfo->name, '"', box->type, box->len
+	  ));
+	size_t hdrlen;
 	if (box->len == 1) {
+		JAS_DBGLOG(10, ("big length\n"));
 		if (jp2_getuint64(in, &extlen)) {
 			goto error;
 		}
-		box->len = (uint_fast32_t)extlen; // JMW?
-		box->data_len = box->len - 8;
+		if (extlen > 0xffffffffUL) {
+			jas_eprintf("warning: cannot handle large 64-bit box length\n");
+			goto error;
+		}
+		box->len = (uint_fast32_t)extlen;
+		hdrlen = JP2_BOX_HDRLEN(true);
+	} else {
+		hdrlen = JP2_BOX_HDRLEN(false);
 	}
-	if (box->len != 0 && box->len < JP2_BOX_HDRLEN) {
+	if (box->len != 0 && box->len < 8) {
+		goto error;
+	}
+	if (box->len > 0x7fffffffUL) {
+		/* this limit is the largest value which can
+		   be passed to jas_stream_copy() without
+		   overflowing */
 		goto error;
 	}
-	box->data_len -= JP2_BOX_HDRLEN;
 
 	dataflag = !(box->info->flags & (JP2_BOX_SUPER | JP2_BOX_NODATA));
 
 	if (dataflag) {
+		if (box->len < hdrlen)
+			goto error;
+		box->datalen = box->len - hdrlen;
+
 		if (!(tmpstream = jas_stream_memopen(0, 0))) {
 			goto error;
 		}
-		if (jas_stream_copy(tmpstream, in, box->len - JP2_BOX_HDRLEN)) {
+		if (jas_stream_copy(tmpstream, in, box->datalen)) {
+			jas_eprintf("cannot copy box data\n");
 			goto error;
 		}
 		jas_stream_rewind(tmpstream);
 
+		// From here onwards, the box data will need to be destroyed.
+		// So, initialize the box operations.
+		box->ops = &boxinfo->ops;
+
 		if (box->ops->getdata) {
 			if ((*box->ops->getdata)(box, tmpstream)) {
+				jas_eprintf("cannot parse box data\n");
 				goto error;
 			}
 		}
 		jas_stream_close(tmpstream);
 	}
 
-#if 0
-	jp2_box_dump(box, stderr);
-#endif
+	if (jas_getdbglevel() >= 1) {
+		jp2_box_dump(box, stderr);
+	}
 
 	return box;
-	abort();
 
 error:
 	if (box) {
@@ -308,6 +363,22 @@ error:
 	return 0;
 }
 
+#ifdef JASPER_DISABLED
+void jp2_box_dump(jp2_box_t *box, FILE *out)
+{
+	const jp2_boxinfo_t *boxinfo;
+	boxinfo = jp2_boxinfolookup(box->type);
+	assert(boxinfo);
+
+	fprintf(out, "JP2 box: ");
+	fprintf(out, "type=%c%s%c (0x%08"PRIxFAST32"); length=%"PRIuFAST32"\n", '"',
+	  boxinfo->name, '"', box->type, box->len);
+	if (box->ops->dumpdata) {
+		(*box->ops->dumpdata)(box, out);
+	}
+}
+#endif /* JASPER_DISABLED */
+
 static int jp2_jp_getdata(jp2_box_t *box, jas_stream_t *in)
 {
 	jp2_jp_t *jp = &box->data.jp;
@@ -319,12 +390,15 @@ static int jp2_jp_getdata(jp2_box_t *box, jas_stream_t *in)
 
 static int jp2_ftyp_getdata(jp2_box_t *box, jas_stream_t *in)
 {
+	if (box->datalen < 8)
+		return -1;
+
 	jp2_ftyp_t *ftyp = &box->data.ftyp;
 	unsigned int i;
 	if (jp2_getuint32(in, &ftyp->majver) || jp2_getuint32(in, &ftyp->minver)) {
 		return -1;
 	}
-	ftyp->numcompatcodes = ((box->len - JP2_BOX_HDRLEN) - 8) / 4;
+	ftyp->numcompatcodes = (box->datalen - 8) / 4;
 	if (ftyp->numcompatcodes > JP2_FTYP_MAXCOMPATCODES) {
 		return -1;
 	}
@@ -336,6 +410,7 @@ static int jp2_ftyp_getdata(jp2_box_t *box, jas_stream_t *in)
 	return 0;
 }
 
+#ifdef ENABLE_JASPER_IMAGE
 static int jp2_ihdr_getdata(jp2_box_t *box, jas_stream_t *in)
 {
 	jp2_ihdr_t *ihdr = &box->data.ihdr;
@@ -350,10 +425,17 @@ static int jp2_ihdr_getdata(jp2_box_t *box, jas_stream_t *in)
 
 static int jp2_bpcc_getdata(jp2_box_t *box, jas_stream_t *in)
 {
+	if (box->datalen > 0xffff)
+		/* excessive number of components - this is a
+		   pessimistic limit, because in jp2_ihdr_getdata(),
+		   it's a 16 bit integer */
+		return -1;
+
 	jp2_bpcc_t *bpcc = &box->data.bpcc;
 	unsigned int i;
-	bpcc->numcmpts = box->len - JP2_BOX_HDRLEN;
-	if (!(bpcc->bpcs = jas_malloc(bpcc->numcmpts * sizeof(uint_fast8_t)))) {
+	bpcc->bpcs = 0;
+	bpcc->numcmpts = box->datalen;
+	if (!(bpcc->bpcs = jas_alloc2(bpcc->numcmpts, sizeof(uint_fast8_t)))) {
 		return -1;
 	}
 	for (i = 0; i < bpcc->numcmpts; ++i) {
@@ -366,6 +448,9 @@ static int jp2_bpcc_getdata(jp2_box_t *box, jas_stream_t *in)
 
 static int jp2_colr_getdata(jp2_box_t *box, jas_stream_t *in)
 {
+	if (box->datalen < 3)
+		return -1;
+
 	jp2_colr_t *colr = &box->data.colr;
 	colr->csid = 0;
 	colr->iccp = 0;
@@ -382,8 +467,15 @@ static int jp2_colr_getdata(jp2_box_t *box, jas_stream_t *in)
 		}
 		break;
 	case JP2_COLR_ICC:
-		colr->iccplen = box->len - JP2_BOX_HDRLEN - 3;
-		if (!(colr->iccp = jas_malloc(colr->iccplen * sizeof(uint_fast8_t)))) {
+		colr->iccplen = box->datalen - 3;
+		if (colr->iccplen > 1024 * 1024)
+			/* refuse to read ICC profiles larger than 1
+			   MB (I have no idea how large ICC profiles
+			   can get, but I believe this limit might be
+			   very pessimistic and should be lowered
+			   further) */
+			return -1;
+		if (!(colr->iccp = jas_alloc2(colr->iccplen, sizeof(uint_fast8_t)))) {
 			return -1;
 		}
 		if (jas_stream_read(in, colr->iccp, colr->iccplen) != colr->iccplen) {
@@ -407,10 +499,11 @@ static int jp2_cdef_getdata(jp2_box_t *box, jas_stream_t *in)
 	jp2_cdef_t *cdef = &box->data.cdef;
 	jp2_cdefchan_t *chan;
 	unsigned int channo;
+	cdef->ents = 0;
 	if (jp2_getuint16(in, &cdef->numchans)) {
 		return -1;
 	}
-	if (!(cdef->ents = jas_malloc(cdef->numchans * sizeof(jp2_cdefchan_t)))) {
+	if (!(cdef->ents = jas_alloc2(cdef->numchans, sizeof(jp2_cdefchan_t)))) {
 		return -1;
 	}
 	for (channo = 0; channo < cdef->numchans; ++channo) {
@@ -422,6 +515,9 @@ static int jp2_cdef_getdata(jp2_box_t *box, jas_stream_t *in)
 	}
 	return 0;
 }
+#endif /* ENABLE_JASPER_IMAGE */
+
+#ifdef JASPER_DISABLED
 
 /******************************************************************************\
 * Box output.
@@ -438,13 +534,15 @@ int jp2_box_put(jp2_box_t *box, jas_stream_t *out)
 	dataflag = !(box->info->flags & (JP2_BOX_SUPER | JP2_BOX_NODATA));
 
 	if (dataflag) {
-		tmpstream = jas_stream_memopen(0, 0);
+		if (!(tmpstream = jas_stream_memopen(0, 0))) {
+			goto error;
+		}
 		if (box->ops->putdata) {
 			if ((*box->ops->putdata)(box, tmpstream)) {
 				goto error;
 			}
 		}
-		box->len = jas_stream_tell(tmpstream) + JP2_BOX_HDRLEN;
+		box->len = jas_stream_tell(tmpstream) + JP2_BOX_HDRLEN(false);
 		jas_stream_rewind(tmpstream);
 	}
 	extlen =
@@ -466,14 +564,15 @@ int jp2_box_put(jp2_box_t *box, jas_stream_t *out)
 	}
 
 	if (dataflag) {
-		if (jas_stream_copy(out, tmpstream, box->len - JP2_BOX_HDRLEN)) {
+		if (jas_stream_copy(out, tmpstream, box->len -
+		  JP2_BOX_HDRLEN(false))) {
+			jas_eprintf("cannot copy box data\n");
 			goto error;
 		}
 		jas_stream_close(tmpstream);
 	}
 
 	return 0;
-	abort();
 
 error:
 
@@ -574,10 +673,13 @@ static int jp2_cdef_putdata(jp2_box_t *box, jas_stream_t *out)
 	return 0;
 }
 
+#endif /* JASPER_DISABLED */
+
 /******************************************************************************\
 * Input operations for primitive types.
 \******************************************************************************/
 
+#ifdef ENABLE_JASPER_IMAGE
 static int jp2_getuint8(jas_stream_t *in, uint_fast8_t *val)
 {
 	int c;
@@ -607,6 +709,7 @@ static int jp2_getuint16(jas_stream_t *in, uint_fast16_t *val)
 	}
 	return 0;
 }
+#endif /* ENABLE_JASPER_IMAGE */
 
 static int jp2_getuint32(jas_stream_t *in, uint_fast32_t *val)
 {
@@ -636,13 +739,25 @@ static int jp2_getuint32(jas_stream_t *in, uint_fast32_t *val)
 
 static int jp2_getuint64(jas_stream_t *in, uint_fast64_t *val)
 {
-	in = 0;
-	val = 0;
-	abort();
-	// JMW don't know what this is...
+	uint_fast64_t tmpval;
+	int i;
+	int c;
+
+	tmpval = 0;
+	for (i = 0; i < 8; ++i) {
+		tmpval <<= 8;
+		if ((c = jas_stream_getc(in)) == EOF) {
+			return -1;
+		}
+		tmpval |= (c & 0xff);
+	}
+	*val = tmpval;
+
 	return 0;
 }
 
+#ifdef JASPER_DISABLED
+
 /******************************************************************************\
 * Output operations for primitive types.
 \******************************************************************************/
@@ -684,13 +799,15 @@ static int jp2_putuint64(jas_stream_t *out, uint_fast64_t val)
 	return 0;
 }
 
+#endif /* JASPER_DISABLED */
+
 /******************************************************************************\
 * Miscellaneous code.
 \******************************************************************************/
 
-jp2_boxinfo_t *jp2_boxinfolookup(int type)
+static const jp2_boxinfo_t *jp2_boxinfolookup(int type)
 {
-	jp2_boxinfo_t *boxinfo;
+	const jp2_boxinfo_t *boxinfo;
 	for (boxinfo = jp2_boxinfos; boxinfo->name; ++boxinfo) {
 		if (boxinfo->type == type) {
 			return boxinfo;
@@ -703,6 +820,7 @@ jp2_boxinfo_t *jp2_boxinfolookup(int type)
 
 
 
+#ifdef ENABLE_JASPER_IMAGE
 static void jp2_cmap_destroy(jp2_box_t *box)
 {
 	jp2_cmap_t *cmap = &box->data.cmap;
@@ -716,9 +834,16 @@ static int jp2_cmap_getdata(jp2_box_t *box, jas_stream_t *in)
 	jp2_cmap_t *cmap = &box->data.cmap;
 	jp2_cmapent_t *ent;
 	unsigned int i;
+	cmap->ents = 0;
 
-	cmap->numchans = (box->len - JP2_BOX_HDRLEN) / 4;
-	if (!(cmap->ents = jas_malloc(cmap->numchans * sizeof(jp2_cmapent_t)))) {
+	cmap->numchans = (box->datalen) / 4;
+	if (cmap->numchans > 0xff)
+		/* excessive number of channels - this is a
+		   pessimistic limit, because in jp2_pclr_getdata(),
+		   it's a 8 bit integer */
+		return -1;
+
+	if (!(cmap->ents = jas_alloc2(cmap->numchans, sizeof(jp2_cmapent_t)))) {
 		return -1;
 	}
 	for (i = 0; i < cmap->numchans; ++i) {
@@ -733,14 +858,16 @@ static int jp2_cmap_getdata(jp2_box_t *box, jas_stream_t *in)
 	return 0;
 }
 
+#ifdef JASPER_DISABLED
 static int jp2_cmap_putdata(jp2_box_t *box, jas_stream_t *out)
 {
 	/* Eliminate compiler warning about unused variables. */
-	box = 0;
-	out = 0;
+	(void)box;
+	(void)out;
 
 	return -1;
 }
+#endif /* JASPER_DISABLED */
 
 static void jp2_pclr_destroy(jp2_box_t *box)
 {
@@ -761,16 +888,23 @@ static int jp2_pclr_getdata(jp2_box_t *box, jas_stream_t *in)
 	int_fast32_t x;
 
 	pclr->lutdata = 0;
+	pclr->bpc = 0;
 
 	if (jp2_getuint16(in, &pclr->numlutents) ||
 	  jp2_getuint8(in, &pclr->numchans)) {
 		return -1;
 	}
-	lutsize = pclr->numlutents * pclr->numchans;
-	if (!(pclr->lutdata = jas_malloc(lutsize * sizeof(int_fast32_t)))) {
+
+	// verify in range data as per I.5.3.4 - Palette box
+	if (pclr->numchans < 1 || pclr->numlutents < 1 || pclr->numlutents > 1024) {
 		return -1;
 	}
-	if (!(pclr->bpc = jas_malloc(pclr->numchans * sizeof(uint_fast8_t)))) {
+
+	lutsize = pclr->numlutents * pclr->numchans;
+	if (!(pclr->lutdata = jas_alloc2(lutsize, sizeof(int_fast32_t)))) {
+		return -1;
+	}
+	if (!(pclr->bpc = jas_alloc2(pclr->numchans, sizeof(uint_fast8_t)))) {
 		return -1;
 	}
 	for (i = 0; i < pclr->numchans; ++i) {
@@ -790,67 +924,34 @@ static int jp2_pclr_getdata(jp2_box_t *box, jas_stream_t *in)
 	return 0;
 }
 
+#ifdef JASPER_DISABLED
 static int jp2_pclr_putdata(jp2_box_t *box, jas_stream_t *out)
 {
 #if 0
 	jp2_pclr_t *pclr = &box->data.pclr;
 #endif
-/* Eliminate warning about unused variable. */
-box = 0;
-out = 0;
+	/* Eliminate warning about unused variable. */
+	(void)box;
+	(void)out;
 	return -1;
 }
+#endif /* JASPER_DISABLED */
 
-static void jp2_uuid_destroy(jp2_box_t *box)
+static void jp2_pclr_dumpdata(jp2_box_t *box, FILE *out)
 {
-	jp2_uuid_t *uuid = &box->data.uuid;
-	if (uuid->data)
-	{
-	    jas_free(uuid->data);
-	    uuid->data = NULL;
+	jp2_pclr_t *pclr = &box->data.pclr;
+	unsigned int i;
+	int j;
+	fprintf(out, "numents=%d; numchans=%d\n", (int) pclr->numlutents,
+	  (int) pclr->numchans);
+	for (i = 0; i < pclr->numlutents; ++i) {
+		for (j = 0; j < pclr->numchans; ++j) {
+			fprintf(out, "LUT[%d][%d]=%"PRIiFAST32"\n", i, j,
+			  pclr->lutdata[i * pclr->numchans + j]);
+		}
 	}
 }
 
-static int jp2_uuid_getdata(jp2_box_t *box, jas_stream_t *in)
-{
-	jp2_uuid_t *uuid = &box->data.uuid;
-	int i;
-	
-	for (i = 0; i < 16; i++)
-	{
-	    if (jp2_getuint8(in, &uuid->uuid[i]))
-		return -1;
-	}
-	
-	uuid->data_len = box->data_len - 16;
-	uuid->data = jas_malloc(uuid->data_len * sizeof(uint_fast8_t));
-	for (i = 0; i < (int)uuid->data_len; i++)
-	{
-	    if (jp2_getuint8(in, &uuid->data[i]))
-		return -1;
-	}
-	return 0;
-}
-
-static int jp2_uuid_putdata(jp2_box_t *box, jas_stream_t *out)
-{
-	jp2_uuid_t *uuid = &box->data.uuid;
-	int i;
-	
-	for (i = 0; i < 16; i++)
-	{
-	    if (jp2_putuint8(out, uuid->uuid[i]))
-		return -1;
-	}
-	
-	for (i = 0; i < (int)uuid->data_len; i++)
-	{
-	    if (jp2_putuint8(out, uuid->data[i]))
-		return -1;
-	}
-	return 0;
-}
-
 static int jp2_getint(jas_stream_t *in, int s, int n, int_fast32_t *val)
 {
 	int c;
@@ -881,6 +982,7 @@ static int jp2_getint(jas_stream_t *in, int s, int n, int_fast32_t *val)
 
 	return 0;
 }
+#endif /* ENABLE_JASPER_IMAGE */
 
 const jp2_cdefchan_t *jp2_cdef_lookup(jp2_cdef_t *cdef, int channo)
 {
