@@ -71,14 +71,16 @@
 * Includes.
 \******************************************************************************/
 
-#include <stdlib.h>
-#include <assert.h>
-#include <ctype.h>
+#include "jpc_cs.h"
 
 #include "jasper/jas_malloc.h"
 #include "jasper/jas_debug.h"
+#include "jasper/jas_image.h"
 
-#include "jpc_cs.h"
+#include <assert.h>
+#include <ctype.h>
+#include <stdlib.h>
+#include <string.h>
 
 /******************************************************************************\
 * Types.
@@ -181,8 +183,8 @@ static const jpc_mstabent_t jpc_mstab[] = {
 	{JPC_MS_QCD, "QCD", {jpc_qcd_destroyparms, jpc_qcd_getparms, }},
 	{JPC_MS_QCC, "QCC", {jpc_qcc_destroyparms, jpc_qcc_getparms, }},
 	{JPC_MS_POC, "POC", {jpc_poc_destroyparms, jpc_poc_getparms, }},
-	{JPC_MS_TLM, "TLM", {0, jpc_unk_getparms}},
-	{JPC_MS_PLM, "PLM", {0, jpc_unk_getparms}},
+	{JPC_MS_TLM, "TLM", {jpc_unk_destroyparms, jpc_unk_getparms}},
+	{JPC_MS_PLM, "PLM", {jpc_unk_destroyparms, jpc_unk_getparms}},
 #ifdef ENABLE_JASPER_PPM
 	{JPC_MS_PPM, "PPM", {jpc_ppm_destroyparms, jpc_ppm_getparms, }},
 	{JPC_MS_PPT, "PPT", {jpc_ppt_destroyparms, jpc_ppt_getparms, }},
@@ -393,7 +395,7 @@ static int jpc_sot_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 	jpc_sot_t *sot = &ms->parms.sot;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_getuint16(in, &sot->tileno) ||
 	  jpc_getuint32(in, &sot->len) ||
@@ -401,8 +403,7 @@ static int jpc_sot_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 	  jpc_getuint8(in, &sot->numparts)) {
 		return -1;
 	}
-	if (sot->tileno > 65534 || sot->len < 12 || sot->partno > 254 ||
-	  sot->numparts > 255) {
+	if (sot->tileno > 65534 || sot->len < 12 || sot->partno > 254) {
 		return -1;
 	}
 	if (jas_stream_eof(in)) {
@@ -417,7 +418,7 @@ static int jpc_sot_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 	jpc_sot_t *sot = &ms->parms.sot;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_putuint16(out, sot->tileno) ||
 	  jpc_putuint32(out, sot->len) ||
@@ -451,7 +452,7 @@ static int jpc_siz_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate,
 	siz->comps = 0;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_getuint16(in, &siz->caps) ||
 	  jpc_getuint32(in, &siz->width) ||
@@ -507,16 +508,20 @@ static int jpc_siz_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate,
 		  jpc_getuint8(in, &siz->comps[i].vsamp)) {
 			goto error;
 		}
-		if (siz->comps[i].hsamp == 0 || siz->comps[i].hsamp > 255) {
+		if (siz->comps[i].hsamp == 0) {
 			jas_eprintf("invalid XRsiz value %d\n", siz->comps[i].hsamp);
 			goto error;
 		}
-		if (siz->comps[i].vsamp == 0 || siz->comps[i].vsamp > 255) {
+		if (siz->comps[i].vsamp == 0) {
 			jas_eprintf("invalid YRsiz value %d\n", siz->comps[i].vsamp);
 			goto error;
 		}
 		siz->comps[i].sgnd = (tmp >> 7) & 1;
 		siz->comps[i].prec = (tmp & 0x7f) + 1;
+		if (siz->comps[i].prec > 38) {
+			jas_eprintf("invalid component bit depth %d\n", siz->comps[i].prec);
+			goto error;
+		}
 	}
 	if (jas_stream_eof(in)) {
 		goto error;
@@ -537,7 +542,7 @@ static int jpc_siz_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 	unsigned int i;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	assert(siz->width && siz->height && siz->tilewidth &&
 	  siz->tileheight && siz->numcomps);
@@ -713,7 +718,7 @@ static int jpc_coc_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 static void jpc_cox_destroycompparms(jpc_coxcp_t *compparms)
 {
 	/* Eliminate compiler warning about unused variables. */
-	compparms = 0;
+	(void)compparms;
 }
 
 static int jpc_cox_getcompparms(jpc_ms_t *ms, jpc_cstate_t *cstate,
@@ -723,8 +728,8 @@ static int jpc_cox_getcompparms(jpc_ms_t *ms, jpc_cstate_t *cstate,
 	int i;
 
 	/* Eliminate compiler warning about unused variables. */
-	ms = 0;
-	cstate = 0;
+	(void)ms;
+	(void)cstate;
 
 	if (jpc_getuint8(in, &compparms->numdlvls) ||
 	  jpc_getuint8(in, &compparms->cblkwidthval) ||
@@ -760,9 +765,7 @@ static int jpc_cox_getcompparms(jpc_ms_t *ms, jpc_cstate_t *cstate,
 	}
 	return 0;
 error:
-	if (compparms) {
-		jpc_cox_destroycompparms(compparms);
-	}
+	jpc_cox_destroycompparms(compparms);
 	return -1;
 }
 
@@ -774,8 +777,8 @@ static int jpc_cox_putcompparms(jpc_ms_t *ms, jpc_cstate_t *cstate,
 	assert(compparms->numdlvls <= 32);
 
 	/* Eliminate compiler warning about unused variables. */
-	ms = 0;
-	cstate = 0;
+	(void)ms;
+	(void)cstate;
 
 	if (jpc_putuint8(out, compparms->numdlvls) ||
 	  jpc_putuint8(out, compparms->cblkwidthval) ||
@@ -944,7 +947,7 @@ static int jpc_qcx_getcompparms(jpc_qcxcp_t *compparms, jpc_cstate_t *cstate,
 	int i;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	n = 0;
 	if (jpc_getuint8(in, &tmp)) {
@@ -978,11 +981,13 @@ static int jpc_qcx_getcompparms(jpc_qcxcp_t *compparms, jpc_cstate_t *cstate,
 		for (i = 0; i < compparms->numstepsizes; ++i) {
 			if (compparms->qntsty == JPC_QCX_NOQNT) {
 				if (jpc_getuint8(in, &tmp)) {
+					jpc_qcx_destroycompparms(compparms);
 					return -1;
 				}
 				compparms->stepsizes[i] = JPC_QCX_EXPN(tmp >> 3);
 			} else {
 				if (jpc_getuint16(in, &compparms->stepsizes[i])) {
+					jpc_qcx_destroycompparms(compparms);
 					return -1;
 				}
 			}
@@ -1004,9 +1009,11 @@ static int jpc_qcx_putcompparms(jpc_qcxcp_t *compparms, jpc_cstate_t *cstate,
 	int i;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
-	jpc_putuint8(out, ((compparms->numguard & 7) << 5) | compparms->qntsty);
+	if (jpc_putuint8(out, ((compparms->numguard & 7) << 5) | compparms->qntsty)) {
+		return -1;
+	}
 	for (i = 0; i < compparms->numstepsizes; ++i) {
 		if (compparms->qntsty == JPC_QCX_NOQNT) {
 			if (jpc_putuint8(out, JPC_QCX_GETEXPN(
@@ -1032,7 +1039,7 @@ static int jpc_sop_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 	jpc_sop_t *sop = &ms->parms.sop;
 
 	/* Eliminate compiler warning about unused variable. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_getuint16(in, &sop->seqno)) {
 		return -1;
@@ -1046,7 +1053,7 @@ static int jpc_sop_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 	jpc_sop_t *sop = &ms->parms.sop;
 
 	/* Eliminate compiler warning about unused variable. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_putuint16(out, sop->seqno)) {
 		return -1;
@@ -1073,7 +1080,7 @@ static int jpc_ppm_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 	jpc_ppm_t *ppm = &ms->parms.ppm;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	ppm->data = 0;
 
@@ -1107,7 +1114,7 @@ static int jpc_ppm_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 	jpc_ppm_t *ppm = &ms->parms.ppm;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	if (JAS_CAST(jas_uint, jas_stream_write(out, (char *) ppm->data, ppm->len)) != ppm->len) {
 		return -1;
@@ -1132,7 +1139,7 @@ static int jpc_ppt_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 	jpc_ppt_t *ppt = &ms->parms.ppt;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	ppt->data = 0;
 
@@ -1165,7 +1172,7 @@ static int jpc_ppt_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 	jpc_ppt_t *ppt = &ms->parms.ppt;
 
 	/* Eliminate compiler warning about unused variable. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_putuint8(out, ppt->ind)) {
 		return -1;
@@ -1309,7 +1316,7 @@ static int jpc_crg_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 	jpc_crgcomp_t *comp;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	for (compno = 0, comp = crg->comps; compno < crg->numcomps; ++compno,
 	  ++comp) {
@@ -1339,7 +1346,7 @@ static int jpc_com_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 	jpc_com_t *com = &ms->parms.com;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_getuint16(in, &com->regid)) {
 		return -1;
@@ -1364,7 +1371,7 @@ static int jpc_com_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *ou
 	jpc_com_t *com = &ms->parms.com;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	if (jpc_putuint16(out, com->regid)) {
 		return -1;
@@ -1395,7 +1402,7 @@ static int jpc_unk_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 	unk->data = 0;
 
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
+	(void)cstate;
 
 	if (ms->len > 0) {
 		if (!(unk->data = jas_alloc2(ms->len, sizeof(unsigned char)))) {
@@ -1418,9 +1425,9 @@ static int jpc_unk_getparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *in
 static int jpc_unk_putparms(jpc_ms_t *ms, jpc_cstate_t *cstate, jas_stream_t *out)
 {
 	/* Eliminate compiler warning about unused variables. */
-	cstate = 0;
-	ms = 0;
-	out = 0;
+	(void)cstate;
+	(void)ms;
+	(void)out;
 
 	/* If this function is called, we are trying to write an unsupported
 	  type of marker segment.  Return with an error indication.  */
