@@ -23,7 +23,7 @@ Copyright_License {
 
 #include "Topography/XShape.hpp"
 #include "Convert.hpp"
-#include "Util/StringAPI.hpp"
+#include "Util/StringAPI.hxx"
 #include "Util/UTF8.hpp"
 #ifdef ENABLE_OPENGL
 #include "Projection/Projection.hpp"
@@ -108,6 +108,12 @@ XShape::XShape(shapefileObj *shpfile, const GeoPoint &file_center, int i,
   msSHPReadShape(shpfile->hSHP, i, &shape);
 
   bounds = ImportRect(shape.bounds);
+  if (!bounds.Check()) {
+    /* malformed bounds */
+    points = nullptr;
+    msFreeShape(&shape);
+    return;
+  }
 
   type = shape.type;
 
