@@ -24,6 +24,10 @@
 #include "harness_wind.hpp"
 #include "test_debug.hpp"
 
+extern "C" {
+#include "tap.h"
+}
+
 int
 main(int argc, char** argv)
 {
